slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSKrylovSchurGetRestart

Gets the restart parameter used in the Krylov-Schur method.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSKrylovSchurGetRestart(EPS eps,PetscReal *keep)

Not Collective

### Input Parameter

| eps | - the eigenproblem solver context

### Output Parameter

| keep | - the restart parameter

### See Also

EPSKrylovSchurSetRestart()

### Level

advanced

### Location

src/eps/impls/krylov/krylovschur/krylovschur.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages